# Contributing
All contributions to is-furry are welcome. Just open a pull request.

Make sure that your code follows the folowing rules:
## Rules
- Run tests after any change to verify that it still works
> yarn run tests
- If you add features which may require tests, add some tests to `tests.ts`
- Don't use semicolons. I know.